@@ -1,16 +1,8 @@
 package SOAP::WSDL::TypeLookup;
-use strict;
-use warnings;
 
-use version; our $VERSION = qv('2.00.07');
-
-my %TYPE_FROM = (
+my %TYPES = (
     # wsdl:
     'http://schemas.xmlsoap.org/wsdl/' => {
-        'import' => {
-            type => 'HANDLER',
-            method => 'wsdl_import',
-        },
         binding => {
             type => 'CLASS',
             class => 'SOAP::WSDL::Binding',
@@ -68,40 +60,28 @@ my %TYPE_FROM = (
     'http://schemas.xmlsoap.org/wsdl/soap/' => {
         operation => {
             type => 'CLASS',
-            class => 'SOAP::WSDL::SOAP::Operation',
+            class => 'SOAP::WSDL::SoapOperation',
         },
         binding => {
             type => 'PARENT',
         },
         body => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::SOAP::Body',
-        },
-        header => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::SOAP::Header',
+            type => 'PARENT',
         },
         address => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::SOAP::Address',
+            type => 'PARENT',
         }
     },
     'http://www.w3.org/2001/XMLSchema' => {
-        'import' => {
-            type => 'HANDLER',
-            method => 'xml_schema_import',
-        },
         schema => {
             type => 'CLASS',
             class => 'SOAP::WSDL::XSD::Schema',
         },
         attribute => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::Attribute',
+            type => 'SKIP'      # not implemented yet
         },
-        attributeGroup  => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::AttributeGroup',
+        attributeGroup => {
+            type => 'SKIP',     # not implemented yet
         },
         key => {
             type => 'SKIP',     # not implemented yet
@@ -114,14 +94,9 @@ my %TYPE_FROM = (
         },
         notation => {
             type => 'SKIP',     # not implemented yet
-        },
+        },      
         annotation => {
-            type => 'CLASS',     # not implemented yet
-            class => 'SOAP::WSDL::XSD::Annotation',
-        },
-        documentation => {
-            type => 'CONTENT',
-            method => 'set_documentation',
+            type => 'SKIP',     # not implemented yet
         },
         appinfo => {
             type => 'SKIP',     # not implemented yet
@@ -155,84 +130,45 @@ my %TYPE_FROM = (
             type => 'METHOD',
             method => 'set_restriction',
         },
-        extension => {
-            type => 'METHOD',
-            method => 'set_extension',
-        },
         list => {
             type => 'METHOD',
             method => 'set_list',
         },
-        union => {
+	union => {
             type => 'METHOD',
             method => 'set_union',
         },
         enumeration => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::Enumeration',
+            type => 'METHOD',
+            method => 'push_enumeration',
         },
         group => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::Group',
-        },
-        all => {
             type => 'METHOD',
-            method => 'set_variety',
+            method => 'set_flavor',
+            value => 'all',
+        },
+	all => {
+            type => 'METHOD',
+            method => 'set_flavor',
             value => 'all',
         },
         choice => {
             type => 'METHOD',
-            method => 'set_variety',
+            method => 'set_flavor',
             value => 'choice',
         },
         sequence => {
             type => 'METHOD',
-            method => 'set_variety',
+            method => 'set_flavor',
             value => 'sequence',
         },
-        value => {
-            type => 'SKIP',
-        },
-        minExclusive => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::MinExclusive',
-        },
-        maxExclusive => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::MaxExclusive',
-        },
-        minInclusive => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::MinInclusive',
-        },
-        maxInclusive => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::MaxInclusive',
-        },
-        maxLength => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::MaxLength',
-        },
-        minLength => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::MinLength',
-        },
-        totalDigits => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::TotalDigits',
-        },
-        fractionDigits => {
-            type => 'CLASS',
-            class => 'SOAP::WSDL::XSD::FractionDigits',
-        },
     },
 );
 
-$TYPE_FROM{ 'http://www.w3.org/2000/10/XMLSchema' } = $TYPE_FROM{ 'http://www.w3.org/2001/XMLSchema' };
 
 sub lookup {
-    my ($self, $namespace, $name) = @_;
-    return $TYPE_FROM{ $namespace }->{ $name };
+	my $self = shift;
+	my $namespace = shift || 'http://schemas.xmlsoap.org/wsdl/';
+	my $name = shift;
+	return $TYPES{ $namespace }->{ $name };
 }
-
-1;
\ No newline at end of file
