@@ -40,7 +40,6 @@ my %char2entity = (
     q{'} => q{&apos;},
 );
 
-
 sub serialize {
     my ($self, $opt) = @_;
     my $ident = ident $self;
@@ -59,27 +58,3 @@ sub serialize {
 }
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-SOAP::WSDL::XSD::Typelib::Builtin::string - string objects
-
-=head1 DESCRIPTION
-
-String objects. XML entities (&, E<lt> E<gt> " ') are encoded on 
-serialization.
-
-=head1 LICENSE
-
-This file is part of SOAP-WSDL. You may distribute/modify it under 
-the same terms as perl itself
-
-=head1 AUTHOR
-
-Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
-
-=cut
\ No newline at end of file
