@@ -9,11 +9,20 @@ use base (
    'SOAP::WSDL::XSD::Typelib::Builtin::string',
 );
 
-sub START {
-   my ($self, $ident, $args_of) =@_;
-   $self->__set_name('MyElementName');
-}
+__PACKAGE__->__set_name('MyElementName');
+sub get_xmlns { 'urn:Test' };
 
+package MyComplexTypeElement;
+use strict;
+use Class::Std::Storable;
+use SOAP::WSDL::XSD::Typelib::Element;
+use MyComplexType;
+use base (
+   'SOAP::WSDL::XSD::Typelib::Element',
+   'MyComplexType',
+);
+
+__PACKAGE__->__set_name('MyComplexTypeElement');
 sub get_xmlns { 'urn:Test' };
 
 package MyTestElement;
@@ -26,10 +35,6 @@ use base (
    'SOAP::WSDL::XSD::Typelib::Builtin::string',
 );
 
-sub START {
-   my ($self, $ident, $args_of) =@_;
-}
-
 __PACKAGE__->__set_name('MyTestElement');
 
 sub get_xmlns { 'urn:Test' };
@@ -44,12 +49,9 @@ use base (
    'SOAP::WSDL::XSD::Typelib::Builtin::string',
 );
 
-sub START {
-   my ($self, $ident, $args_of) =@_;
-   $self->__set_name('MyTestElement2');
-}
+__PACKAGE__->__set_name('MyTestElement2');
+
 sub get_xmlns { 'urn:Test' };
-;
 
 
 package MyAtomicComplexTypeElement;
@@ -76,6 +78,7 @@ __PACKAGE__->_factory(
         test2 => \%test2_of,
     },
     {
+        # this is the <element ref="" variant....
         test =>  'MyTestElement',
         test2 => 'MyTestElement2',
     },
@@ -83,5 +86,4 @@ __PACKAGE__->_factory(
 
 __PACKAGE__->__set_name('MyAtomicComplexTypeElement');
 
-
 1;
